@@ -6,40 +6,45 @@
 #include "../projectexplorer_export.h"
 
 #include "idevice.h"
-#include "idevicefactory.h"
 
 #include <QApplication>
 
+#include <memory>
+
 namespace ProjectExplorer {
 class ProjectExplorerPlugin;
+class DesktopDevicePrivate;
 
 namespace Internal { class DesktopDeviceFactory; }
 
 class PROJECTEXPLORER_EXPORT DesktopDevice : public IDevice
 {
 public:
+    ~DesktopDevice() override;
+
     IDevice::DeviceInfo deviceInformation() const override;
 
     IDeviceWidget *createWidget() override;
-    bool canAutoDetectPorts() const override;
     bool canCreateProcessModel() const override;
-    DeviceProcessList *createProcessListModel(QObject *parent) const override;
-    ProjectExplorer::PortsGatheringMethod portsGatheringMethod() const override;
     DeviceProcessSignalOperation::Ptr signalOperation() const override;
     QUrl toolControlChannel(const ControlChannelHint &) const override;
     bool usableAsBuildDevice() const override;
 
     bool handlesFile(const Utils::FilePath &filePath) const override;
-    Utils::Environment systemEnvironment() const override;
+    Utils::expected_str<Utils::Environment> systemEnvironmentWithError() const override;
 
     Utils::FilePath rootPath() const override;
     Utils::FilePath filePath(const QString &pathOnDevice) const override;
 
+    void fromMap(const Utils::Store &map) override;
+
 protected:
     DesktopDevice();
 
     friend class ProjectExplorerPlugin;
     friend class Internal::DesktopDeviceFactory;
+
+    std::unique_ptr<DesktopDevicePrivate> d;
 };
 
 } // namespace ProjectExplorer
